@@ -1,8 +1,6 @@
-from __future__ import absolute_import
+__version__ = '1.2'
 
-__version__ = '1.1'
-
-from .backup_schedules import (BackupSchedule, BackupScheduleManager, 
+from cloudservers.backup_schedules import (BackupSchedule, BackupScheduleManager, 
         BACKUP_WEEKLY_DISABLED, BACKUP_WEEKLY_SUNDAY, BACKUP_WEEKLY_MONDAY,
         BACKUP_WEEKLY_TUESDAY, BACKUP_WEEKLY_WEDNESDAY,
         BACKUP_WEEKLY_THURSDAY, BACKUP_WEEKLY_FRIDAY, BACKUP_WEEKLY_SATURDAY,
@@ -13,13 +11,13 @@ from .backup_schedules import (BackupSchedule, BackupScheduleManager,
         BACKUP_DAILY_H_1400_1600, BACKUP_DAILY_H_1600_1800,
         BACKUP_DAILY_H_1800_2000, BACKUP_DAILY_H_2000_2200,
         BACKUP_DAILY_H_2200_0000)
-from .client import CloudServersClient
-from .exceptions import (CloudServersException, BadRequest, Unauthorized,
+from cloudservers.client import CloudServersClient
+from cloudservers.exceptions import (CloudServersException, BadRequest, Unauthorized,
     Forbidden, NotFound, OverLimit)
-from .flavors import FlavorManager, Flavor
-from .images import ImageManager, Image
-from .ipgroups import IPGroupManager, IPGroup
-from .servers import ServerManager, Server, REBOOT_HARD, REBOOT_SOFT
+from cloudservers.flavors import FlavorManager, Flavor
+from cloudservers.images import ImageManager, Image
+from cloudservers.ipgroups import IPGroupManager, IPGroup
+from cloudservers.servers import ServerManager, Server, REBOOT_HARD, REBOOT_SOFT
 
 class CloudServers(object):
     """
