@@ -190,7 +190,7 @@ class CloudserversShell(object):
     @arg('--ipgroup',
          default = None, 
          metavar = '<group>',
-         help = "IP group ID (see 'cloudservers ipgroup-list').")
+         help = "IP group name or ID (see 'cloudservers ipgroup-list').")
     @arg('--meta', 
          metavar = "<key=value>", 
          action = 'append',
@@ -215,6 +215,13 @@ class CloudserversShell(object):
         flavor = args.flavor or self.cs.flavors.find(ram=256)
         image = args.image or self.cs.images.find(name="Ubuntu 10.04 LTS (lucid)")
         
+        # Map --ipgroup <name> to an ID.
+        # XXX do this for flavor/image?
+        if args.ipgroup:
+            ipgroup = self._find_ipgroup(args.ipgroup)
+        else:
+            ipgroup = None
+        
         metadata = dict(v.split('=') for v in args.meta)
             
         files = {}
@@ -245,7 +252,7 @@ class CloudserversShell(object):
             except IOError, e:
                 raise CommandError("Can't open '%s': %s" % (keyfile, e))
         
-        server = self.cs.servers.create(args.name, image, flavor, args.ipgroup, metadata, files)
+        server = self.cs.servers.create(args.name, image, flavor, ipgroup, metadata, files)
         print_dict(server._info)
     
     def do_flavor_list(self, args):
@@ -293,7 +300,12 @@ class CloudserversShell(object):
 
     def do_ipgroup_list(self, args):
         """Show IP groups."""
-        print_list(self.cs.ipgroups.list(), ['ID', 'Name', 'Servers'])
+        def pretty_server_list(ipgroup):
+            return ", ".join(self.cs.servers.get(id).name for id in ipgroup.servers)
+            
+        print_list(self.cs.ipgroups.list(), 
+                   fields = ['ID', 'Name', 'Server List'], 
+                   formatters = {'Server List': pretty_server_list})
         
     @arg('group', metavar='<group>', help='Name or ID of group.')
     def do_ipgroup_show(self, args):
@@ -435,11 +447,19 @@ class CloudserversHelpFormatter(argparse.HelpFormatter):
         super(CloudserversHelpFormatter, self).start_section(heading)
 
 # Helpers
-def print_list(objs, fields):
+def print_list(objs, fields, formatters={}):
     pt = prettytable.PrettyTable([f for f in fields], caching=False)
     pt.aligns = ['l' for f in fields]
+    
     for o in objs:
-        pt.add_row([getattr(o, f.lower().replace(' ', '_'), '') for f in fields])
+        row = []
+        for field in fields:
+            if field in formatters:
+                row.append(formatters[field](o))
+            else:
+                row.append(getattr(o, field.lower().replace(' ', '_'), ''))
+        pt.add_row(row)
+    
     pt.printt(sortby=fields[0])
     
 def print_dict(d):
