@@ -6,15 +6,13 @@ wrong the tests might fail. I've indicated in comments the places where actual
 behavior differs from the spec.
 """
 
-from __future__ import absolute_import
-
 import httplib2
 import urlparse
 import urllib
 from nose.tools import assert_equal
 from cloudservers import CloudServers
 from cloudservers.client import CloudServersClient
-from .utils import fail, assert_in, assert_not_in, assert_has_keys
+from utils import fail, assert_in, assert_not_in, assert_has_keys
 
 class FakeServer(CloudServers):
     def __init__(self, username=None, password=None):
@@ -187,6 +185,10 @@ class FakeClient(CloudServersClient):
         r = {'server': self.get_servers_detail()[1]['servers'][0]}
         return (200, r)
 
+    def get_servers_5678(self, **kw):
+        r = {'server': self.get_servers_detail()[1]['servers'][1]}
+        return (200, r)
+
     def put_servers_1234(self, body, **kw):
         assert_equal(body.keys(), ['server'])
         assert_has_keys(body['server'], optional=['name', 'adminPass'])
