@@ -11,7 +11,9 @@ def test_authenticate_success():
         'x-auth-token': '1b751d74-de0c-46ae-84f0-915744b582d1',
     })
     mock_request = mock.Mock(return_value=(auth_response, None))
-    with mock.patch_object(httplib2.Http, "request", mock_request):
+    
+    @mock.patch.object(httplib2.Http, "request", mock_request)
+    def test_auth_call():
         cs.client.authenticate()
         mock_request.assert_called_with(cs.client.AUTH_URL, 'GET', 
             headers = {
@@ -22,25 +24,39 @@ def test_authenticate_success():
         assert_equal(cs.client.management_url, auth_response['x-server-management-url'])
         assert_equal(cs.client.auth_token, auth_response['x-auth-token'])
 
+    test_auth_call()
+
 def test_authenticate_failure():
     cs = cloudservers.CloudServers("username", "apikey")
     auth_response = httplib2.Response({'status': 401})
     mock_request = mock.Mock(return_value=(auth_response, None))
-    with mock.patch_object(httplib2.Http, "request", mock_request):
+    
+    @mock.patch.object(httplib2.Http, "request", mock_request)
+    def test_auth_call():
         assert_raises(cloudservers.Unauthorized, cs.client.authenticate)
         
+    test_auth_call()
+        
 def test_auth_automatic():
     client = cloudservers.CloudServers("username", "apikey").client
     client.management_url = ''
     mock_request = mock.Mock(return_value=(None, None))
-    with mock.patch_object(client, 'request', mock_request):
-        with mock.patch_object(client, 'authenticate') as mock_authenticate:
-            client.get('/')
-            mock_authenticate.assert_called()
-            mock_request.assert_called()
-            
+    
+    @mock.patch.object(client, 'request', mock_request)
+    @mock.patch.object(client, 'authenticate')
+    def test_auth_call(m):
+        client.get('/')
+        m.assert_called()
+        mock_request.assert_called()
+    
+    test_auth_call()
+    
 def test_auth_manual():
     cs = cloudservers.CloudServers("username", "password")
-    with mock.patch_object(cs.client, 'authenticate') as mocked:
+    
+    @mock.patch.object(cs.client, 'authenticate')
+    def test_auth_call(m):
         cs.authenticate()
-        mocked.assert_called()
\ No newline at end of file
+        m.assert_called()
+
+    test_auth_call()
\ No newline at end of file
