@@ -15,17 +15,23 @@ def client():
 
 def test_get():
     cl = client()
-    with mock.patch_object(httplib2.Http, "request", mock_request):
-        with mock.patch('time.time', mock.Mock(return_value=1234)):
-            resp, body = cl.get("/hi")
-            mock_request.assert_called_with("http://example.com/hi?fresh=1234", "GET", 
-                headers={"X-Auth-Token": "token", "User-Agent": cl.USER_AGENT})
-            # Automatic JSON parsing
-            assert_equal(body, {"hi":"there"})
+    
+    @mock.patch.object(httplib2.Http, "request", mock_request)
+    @mock.patch('time.time', mock.Mock(return_value=1234))
+    def test_get_call():
+        resp, body = cl.get("/hi")
+        mock_request.assert_called_with("http://example.com/hi?fresh=1234", "GET", 
+            headers={"X-Auth-Token": "token", "User-Agent": cl.USER_AGENT})
+        # Automatic JSON parsing
+        assert_equal(body, {"hi":"there"})
+
+    test_get_call()
 
 def test_post():
     cl = client()
-    with mock.patch_object(httplib2.Http, "request", mock_request):
+    
+    @mock.patch.object(httplib2.Http, "request", mock_request)
+    def test_post_call():
         cl.post("/hi", body=[1, 2, 3])
         mock_request.assert_called_with("http://example.com/hi", "POST", 
             headers = {
@@ -33,4 +39,6 @@ def test_post():
                 "Content-Type": "application/json",
                 "User-Agent": cl.USER_AGENT},
             body = '[1, 2, 3]'
-        )
\ No newline at end of file
+        )
+    
+    test_post_call()
\ No newline at end of file
