@@ -1,12 +1,10 @@
-from __future__ import absolute_import
-
 import os
 import mock
 import httplib2
-from contextlib import nested
 from nose.tools import assert_raises, assert_equal
 from cloudservers.shell import CloudserversShell, CommandError
-from .fakeserver import FakeServer
+from fakeserver import FakeServer
+from utils import assert_in
 
 # Patch os.environ to avoid required auth info.
 def setup():
@@ -98,8 +96,9 @@ def test_boot_key_auto():
     mock_open.return_value = mock.Mock()
     mock_open.return_value.read = mock.Mock(return_value='SSHKEY')
     
-    with nested(mock.patch('os.path.exists', mock_exists),
-                mock.patch('__builtin__.open', mock_open)):
+    @mock.patch('os.path.exists', mock_exists)
+    @mock.patch('__builtin__.open', mock_open)
+    def test_shell_call():
         shell('boot some-server --image 1 --key')
         assert_called(
             'POST', '/servers',
@@ -110,11 +109,17 @@ def test_boot_key_auto():
                         ]}
             }
         )
+        
+    test_shell_call()
 
 def test_boot_key_auto_no_keys():
     mock_exists = mock.Mock(return_value=False)
-    with mock.patch('os.path.exists', mock_exists):
+    
+    @mock.patch('os.path.exists', mock_exists)
+    def test_shell_call():
         assert_raises(CommandError, shell, 'boot some-server --image 1 --key')
+    
+    test_shell_call()
 
 def test_boot_key_file():
     testfile = os.path.join(os.path.dirname(__file__), 'testfile.txt')
@@ -133,6 +138,20 @@ def test_boot_invalid_keyfile():
     invalid_file = os.path.join(os.path.dirname(__file__), 'asdfasdfasdfasdf')
     assert_raises(CommandError, shell, 'boot some-server --image 1 --key %s' % invalid_file)
 
+def test_boot_ipgroup():
+    shell('boot --image 1 --ipgroup 1 some-server')
+    assert_called(
+        'POST', '/servers',
+        {'server': {'flavorId': 1, 'name': 'some-server', 'imageId': 1, 'sharedIpGroupId': 1}}
+    )
+
+def test_boot_ipgroup_name():
+    shell('boot --image 1 --ipgroup group1 some-server')
+    assert_called(
+        'POST', '/servers',
+        {'server': {'flavorId': 1, 'name': 'some-server', 'imageId': 1, 'sharedIpGroupId': 1}}
+    )
+
 def test_flavor_list():
     shell('flavor-list')
     assert_called('GET', '/flavors/detail')
@@ -165,7 +184,8 @@ def test_ip_unshare():
     
 def test_ipgroup_list():
     shell('ipgroup-list')
-    assert_called('GET', '/shared_ip_groups/detail')
+    assert_in(('GET', '/shared_ip_groups/detail', None), _shell.cs.client.callstack)
+    assert_called('GET', '/servers/5678')
     
 def test_ipgroup_show():
     shell('ipgroup-show 1')
@@ -238,15 +258,22 @@ def test_delete():
     assert_called('DELETE', '/servers/1234')
     
 def test_help():
-    with mock.patch_object(_shell.parser, 'print_help') as m:
+    @mock.patch.object(_shell.parser, 'print_help')
+    def test_help(m):
         shell('help')
         m.assert_called()
-    with mock.patch_object(_shell.subcommands['delete'], 'print_help') as m:
+        
+    @mock.patch.object(_shell.subcommands['delete'], 'print_help')
+    def test_help_delete(m):
         shell('help delete')
         m.assert_called()
+        
+    test_help()
+    test_help_delete()
+        
     assert_raises(CommandError, shell, 'help foofoo')
 
 def test_debug():
     httplib2.debuglevel = 0
     shell('--debug list')
-    assert httplib2.debuglevel == 1
\ No newline at end of file
+    assert httplib2.debuglevel == 1
